#ifndef DEFINE_ISLIB_GET_NUMBER_OF_FIGURES_HPP

#define DEFINE_ISLIB_GET_NUMBER_OF_FIGURES_HPP

//
// Inclusion of standard header file
//
#include <cstddef>

namespace islib
  {
    //
    // Declaration of function
    //
    std::size_t get_number_of_figures ( int );
  }

#endif // DEFINE_ISLIB_GET_NUMBER_OF_FIGURES_HPP

//
// End of file
//
